onepassword-sys 0.1.0

Mostly raw bindings to the 1Password SDK
docs.rs failed to build onepassword-sys-0.1.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: onepassword-sys-0.1.1

Mostly raw bindings to the 1Password SDK.

Setup

The dynamic libraries required can be downloaded from https://github.com/1Password/onepassword-sdk-python/tree/main/src/onepassword/lib

Notes

pollster is included because getting a client ID requires polling a future no matter what, but since it's our own future we know pollster works fine.